@@ -177,7 +177,7 @@ class NetworkManager(NMDbusInterface):
                 if 'cloned-mac-address' in settings[key]:
                     settings[key]['cloned-mac-address'] = fixups.mac_to_dbus(settings[key]['cloned-mac-address'])
                 if 'bssid' in settings[key]:
-                    settings[key]['bssid'] = fixups.mac_to_dbus(settings[key]['mac-address'])
+                    settings[key]['bssid'] = fixups.mac_to_dbus(settings[key]['bssid'])
             if 'ssid' in settings.get('802-11-wireless', {}):
                 settings['802-11-wireless']['ssid'] = fixups.ssid_to_dbus(settings['802-11-wireless']['ssid'])
             if 'ipv4' in settings:
